#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 smtLib
version:              1.1
visibility:           public
id:                   smtLib-1.1-GDndzwsFmmFLKndsULsAIa
key:                  smtLib-1.1-GDndzwsFmmFLKndsULsAIa
license:              BSD-3-Clause
maintainer:           iavor.diatchki@gmail.com
author:               Iavor S. Diatchki
synopsis:             A library for working with the SMTLIB format.
description:          A library for working with the SMTLIB format.
category:             SMT
abi:                  b46458c156be39840d9a783fdafee0ad
exposed:              True
exposed-modules:
    SMTLib1 SMTLib1.QF_AUFBV SMTLib1.QF_BV SMTLib2 SMTLib2.Array
    SMTLib2.BitVector SMTLib2.Compat1 SMTLib2.Core SMTLib2.Int

hidden-modules:       SMTLib1.AST SMTLib1.PP SMTLib2.AST SMTLib2.PP
import-dirs:          /usr/lib/ghc-8.10.5/site-local/smtLib-1.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/smtLib-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/smtLib-1.1
hs-libraries:         HSsmtLib-1.1-GDndzwsFmmFLKndsULsAIa
depends:              base-4.14.2.0 pretty-1.1.3.6
haddock-interfaces:   /usr/share/doc/haskell-smtlib/html/smtLib.haddock
haddock-html:         /usr/share/doc/haskell-smtlib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

